from typing import Union
import json
from requests import Request, Session
from aiohttp import ClientSession

from .enums import *
from .classes import *
from .exceptions import * 


class TGStatSync:

    base_url = "https://api.tgstat.ru"
    
    def __init__(self, token, **kwargs):
        self.token = token
        self.session = Session()
        if not kwargs.get("tests", False):
            result = self.session.get(self.base_url + "/usage/stat", params={"token":token}).json()
            if result['status'] == "error":
                raise TGStatAuthError(result["error"])
            
        
    def _send_request(self, method: RequestsMethods, url: str, **kwargs):
        kwargs["token"] = self.token
        response = self.session.request(method=method.value, url=url, params=kwargs)
        return response.json()
    
    
    def _check_catgory(self, category, api_request):
        if not type(api_request) in [ChannelsRequests, PostsRequests, StoriesRequests, WordsRequests,
                                        CallbackRequests, UsageRequests, DatabaseRequests]:
            raise TGStatTypeError(type(api_request), [ChannelsRequests, PostsRequests, StoriesRequests, WordsRequests,
                                        CallbackRequests, UsageRequests, DatabaseRequests], api_request._name_)
        
        return True

    
    def _build_result(self, data, api_request: Union[
                    ChannelsRequests, PostsRequests, StoriesRequests, WordsRequests,
                    CallbackRequests, UsageRequests, DatabaseRequests
                ]):
        self._check_catgory(api_request)

        if isinstance(data, str):
            try:
                data = json.loads(data)
            except:
                raise TGStatException("Incorrect data value")

        if data['status'] == "error":
            raise TGStatAPIError(data["error"])
        
        class_parser = None
        kwargs = {}
        return_type = ReturnTypes.OBJECT
        if api_request in [ChannelsRequests.SEARCH, ChannelsRequests.POSTS, ChannelsRequests.STORIES,
                            ChannelsRequests.MENTIONS, ChannelsRequests.FORWARDS, PostsRequests.SEARCH,
                             WordsRequests.MENTIONS_BY_CHANNELS]:
            class_parser = MassiveResult
            
            key = "result_type"

            value_dict = {
                ChannelsRequests.SEARCH: ResultsType.CHANNELS,
                ChannelsRequests.POSTS: ResultsType.POST, 
                PostsRequests.SEARCH: ResultsType.POST,
                ChannelsRequests.STORIES: ResultsType.STORIES,
                ChannelsRequests.FORWARDS: ResultsType.FORWARDS,
                ChannelsRequests.MENTIONS:ResultsType.MENTIONS, 
                WordsRequests.MENTIONS_BY_CHANNELS:ResultsType.MENTIONS_CHANNEL
            }

            try:
                kwargs[key] = value_dict[api_request]
            except:
                raise TGStatException("Unsupported Enum")
            
            kwargs.update(data["response"])
        
        elif api_request in [
                                ChannelsRequests.SUBSCRIBERS, ChannelsRequests.VIEWS, ChannelsRequests.AVG_POSTS_REACH,
                                ChannelsRequests.ER, ChannelsRequests.ERR, ChannelsRequests.ERR24,
                                WordsRequests.MENTIONS_BY_PERIOD
                            ]:

            class_parser = DynamicData
            
            key = "dynamic_type"

            value_dict = {
                ChannelsRequests.SUBSCRIBERS: DynamicType.SUBSCRIBERS,
                ChannelsRequests.VIEWS: DynamicType.VIEWS,
                ChannelsRequests.AVG_POSTS_REACH: DynamicType.AVG_POSTS_REACH,
                ChannelsRequests.ER: DynamicType.ER,
                ChannelsRequests.ERR: DynamicType.ERR,
                ChannelsRequests.ERR24: DynamicType.ERR24,
                WordsRequests.MENTIONS_BY_PERIOD: DynamicType.MENTIONS_BY_PERIOD,
            }

            try:
                kwargs[key] = value_dict[api_request]
            except:
                raise TGStatException("Unsupported Enum")

            return_type = ReturnTypes.LIST 
        
        elif api_request in [ChannelsRequests.GET, PostsRequests.GET, StoriesRequests.GET,
            ChannelsRequests.STAT, PostsRequests.STAT, StoriesRequests.STAT, 
            PostsRequests.STAT_MULTI, StoriesRequests.STAT_MULTI]:
            
            objects_dict = {
                ChannelsRequests.GET: Channel,
                PostsRequests.GET: Post,
                StoriesRequests.GET: Story,
                ChannelsRequests.STAT: ChannelStatistic,
                PostsRequests.STAT: GroupStatistic,
                StoriesRequests.STAT: GroupStatistic,
                PostsRequests.STAT_MULTI: UnionStatistic,
                StoriesRequests.STAT_MULTI: UnionStatistic
            }

            try:
                class_parser = objects_dict[api_request]
            except:
                raise TGStatException("Unsupported Enum")
            
            if api_request not in [PostsRequests.STAT_MULTI, StoriesRequests.STAT_MULTI]:
                kwargs.update(data["response"])
            else:
                return_type = ReturnTypes.LIST
        
        elif isinstance(api_request, DatabaseRequests):
            class_parser = DatabaseEntity

            database_types = {
                DatabaseRequests.CATEGORIES: DatabaseTypes.CATEGORIES,
                DatabaseRequests.COUNTRIES: DatabaseTypes.COUNTRIES,
                DatabaseRequests.LANGUAGES: DatabaseTypes.LANGUAGES,
            }

            try:
                kwargs["database_type"] = database_types[api_request]
            except:
                raise TGStatException("Unsupported Enum")
            
            return_type = ReturnTypes.LIST

        
        if return_type == ReturnTypes.OBJECT:
            return class_parser(**kwargs)

        elif return_type == ReturnTypes.LIST:
            return_datas = []
            for temp_data in data["response"]:
                if not isinstance(temp_data, str):
                    return_datas.append(class_parser(**kwargs, **temp_data))
                else:
                    for temp_data_two in data["response"][temp_data]:
                        return_datas.append(class_parser(**kwargs, **temp_data_two))
            
            return return_datas


    def get_result(self, data, api_request: Union[
                    ChannelsRequests, PostsRequests, StoriesRequests, WordsRequests,
                    CallbackRequests, UsageRequests, DatabaseRequests
                ]):
                
        self._check_catgory(api_request)

        return self._build_result(data, api_request)


    def api(self, api_request: Union[
                    ChannelsRequests, PostsRequests, StoriesRequests, WordsRequests,
                    CallbackRequests, UsageRequests, DatabaseRequests
                ], 
            **kwargs):

        self._check_catgory(api_request)

        request_types = {
            ChannelsRequests: RequestsCategory.CHANNELS,
            PostsRequests: RequestsCategory.POSTS,
            StoriesRequests: RequestsCategory.STORIES,
            WordsRequests: RequestsCategory.WORDS,
            CallbackRequests: RequestsCategory.CALLBACK,
            UsageRequests: RequestsCategory.USAGE,
            DatabaseRequests: RequestsCategory.DATABASE
        }

        category = request_types.get(api_request, False)

        if not category:
            raise TGStatTypeError(type(api_request), [ChannelsRequests, PostsRequests, StoriesRequests, WordsRequests,
                    CallbackRequests, UsageRequests, DatabaseRequests], "api_request")

        first_postfix = category.value
        last_postfix, method = api_request.value
        sending_url = self.base_url + "/" + first_postfix + "/" + last_postfix
        response = self._send_request(method, sending_url, **kwargs)
        result = self._build_result(response, api_request)

        return result





class TGStatException(Exception):
    def __init__(self, message=None):
        self.message = message
        super().__init__(message)


class TGStatTypeError(TGStatException):
    def __init__(self, get_type, need_type, var_name):
        self.message = f"The resulting type {get_type} does not match the type {need_type} in variable {var_name}"
        super().__init__(self.message)


class TGStatAPIError(TGStatException):
    def __init__(self, message):
        self.message = message
        super().__init__(message)


class TGStatAuthError(TGStatException):
    def __init__(self, message):
        self.message = message
        super().__init__(message)


"""
:authors: Evgeny Momotov (KrymmyEM)
:license: MIT License
Copyright: (c) 2024 Evgeny
"""

from .enums import *
from .classes import *
from .exceptions import *
from .tg_stat import TGStatSync

__author__ = "KrymmyEM"
__version__ = "0.1.8"


from .enums import DatabaseTypes, ResultsType


class Channel:
    def __init__(
            self, id, link, username,
            title, about, image100, image640, participants_count, peer_type=None, 
            active_usernames=None, tgstat_restrictions = None, tg_id = None,
            category = None, country = None, language = None, **kwargs
        ):
        self.id = id
        self.tg_id = tg_id
        self.link = link
        self.peer_type = peer_type
        self.username = username
        self.active_usernames = active_usernames
        self.title = title
        self.about = about
        self.image100 = image100
        self.image640 = image640
        self.participants_count = participants_count
        self.tgstat_restrictions = tgstat_restrictions
        self.category = None
        self.country = None
        self.language = None
        for key, value in kwargs.items():
            setattr(self, key, value)



class ChannelStatistic:
    def __init__(self, id, title, username, peer_type, participants_count,
                 avg_post_reach=None, adv_post_reach_12h=None, adv_post_reach_24h=None, adv_post_reach_48h=None,
                 err_percent=None, err24_percent=None, er_percent=None, daily_reach=None, ci_index=None,
                 mentions_count=None, forwards_count=None, mentioning_channels_count=None, posts_count=None,
                 dau=None, wau=None, mau=None, online_count_day_time=None, online_count_night_time=None,
                 messages_count_yesterday=None, messages_count_last_week=None, messages_count_last_month=None,
                 messages_count_total=None, **kwargs):
        self.id = id
        self.title = title
        self.username = username
        self.peer_type = peer_type
        self.participants_count = participants_count
        self.avg_post_reach = avg_post_reach
        self.adv_post_reach_12h = adv_post_reach_12h
        self.adv_post_reach_24h = adv_post_reach_24h
        self.adv_post_reach_48h = adv_post_reach_48h
        self.err_percent = err_percent
        self.err24_percent = err24_percent
        self.er_percent = er_percent
        self.daily_reach = daily_reach
        self.ci_index = ci_index
        self.mentions_count = mentions_count
        self.forwards_count = forwards_count
        self.mentioning_channels_count = mentioning_channels_count
        self.posts_count = posts_count
        self.dau = dau
        self.wau = wau
        self.mau = mau
        self.online_count_day_time = online_count_day_time
        self.online_count_night_time = online_count_night_time
        self.messages_count_yesterday = messages_count_yesterday
        self.messages_count_last_week = messages_count_last_week
        self.messages_count_last_month = messages_count_last_month
        self.messages_count_total = messages_count_total
        for key, value in kwargs.items():
            setattr(self, key, value)


class Media:
    def __init__(self, **kwargs):
        # kwargs содержит дополнительные аргументы, которые могут быть переданы
        for key, value in kwargs.items():
            setattr(self, key, value)


class Story:
    def __init__(
        self, id, date, views, link,
        channel_id, is_expired, expire_at,
        caption, media, **kwargs
        ):
        self.id = id
        self.date = date
        self.views = views
        self.link = link
        self.channel_id = channel_id
        self.is_expired = is_expired
        self.expire_at = expire_at
        self.caption = caption
        self.media = None
        if media:
            self.media = Media(**media)

        for key, value in kwargs.items():
            setattr(self, key, value)


class User:
    def __init__(
        self, id, tg_id, username, 
        firstname, lastname, **kwargs
        ):
        self.id = id
        self.tg_id = tg_id
        self.username = username
        self.firstname = firstname
        self.lastname = lastname
        for key, value in kwargs.items():
            setattr(self, key, value)


class Mention:
    def __init__(self, mentionId, mentionType, postId, postLink, postDate, channelId = None, **kwargs):
        self.mentionId = mentionId
        self.mentionType = mentionType
        self.postId = postId
        self.postLink = postLink
        self.postDate = postDate
        self.channelId = channelId
        for key, value in kwargs.items():
            setattr(self, key, value)



class Forward:
    def __init__(self, postId, postLink, channelId, peerType=None, postDate=None, forwardId=0, sourcePostId=0, **kwargs):
        if forwardId:
            self.forwardId = forwardId
        
        if sourcePostId:
            self.sourcePostId = sourcePostId

        self.postId = postId
        self.postLink = postLink
        self.channelId = channelId
        self.peerType = peerType
        self.postDate = postDate
        for key, value in kwargs.items():
            setattr(self, key, value)



class Post:
    def __init__(
            self, id = None, date = None, views = None, link = "",
            channel_id = None, forwarded_from = [], 
            user_id = None, is_deleted = False, deleted_at="", 
            group_id=None, text="", snippet="", media = [], shares_count= None,
            comments_count = None, reactions_count = None
        , **kwargs):
        self.id = id
        self.date = date
        self.views = views
        self.link = link
        self.channel_id = channel_id
        self.forwarded_from = None
        if forwarded_from:
            self.forwarded_from = Forward(**forwarded_from)

        self.user_id = user_id
        self.is_deleted = is_deleted
        self.deleted_at = deleted_at
        self.group_id = group_id
        self.text = text
        self.snippet = snippet
        self.media = None
        if media:
            self.media = Media(**media)

        self.shares_count = shares_count
        self.comments_count = comments_count
        for key, value in kwargs.items():
            setattr(self, key, value)



class MentionChannel:
    def __init__(self, channel_id, mentions_count, views_count, last_mention_date, **kwargs):
        self.channel_id = channel_id
        self.mentions_count = mentions_count
        self.views_count = views_count
        self.last_mention_date = last_mention_date
        for key, value in kwargs.items():
            setattr(self, key, value)



class UnionStatistic:
    def __init__(self, viewsCount, sharesCount, reactionsCount, commentsCount=0, postId=0, storyId=0, **kwargs):
        if postId:
            self.postId = postId
        if storyId:
            self.storyId = storyId
        self.viewsCount = viewsCount
        self.sharesCount = sharesCount
        self.commentsCount = commentsCount
        self.reactionsCount = reactionsCount
        for key, value in kwargs.items():
            setattr(self, key, value)



class View:
    def __init__(self, date, viewsGrowth, **kwargs):
        self.date = date
        self.viewsGrowth = viewsGrowth
        for key, value in kwargs.items():
            setattr(self, key, value)



class GroupStatistic:
    def __init__(self, viewsCount=None, sharesCount=None, commentsCount=None, reactionsCount=None, forwardsCount=None, mentionsCount=None, forwards=[], mentions=[], views=[], **kwargs):
        self.viewsCount = viewsCount
        self.sharesCount = sharesCount
        self.commentsCount = commentsCount
        self.reactionsCount = reactionsCount
        self.forwardsCount = forwardsCount
        self.mentionsCount = mentionsCount
        if forwards:
            self.forwards = [Forward(**fwd) for fwd in forwards]
        if mentions:
            self.mentions = [Mention(**mention) for mention in mentions]
        if views:
            self.views = [View(**view) for view in views]

        for key, value in kwargs.items():
            setattr(self, key, value)



class CallbackNotify:
    def __init__(
        self, subscription_id,
        subscription_type, event_id,
        event_type, **kwargs
        ):
        self.subscription_id = subscription_id
        self.subscription_type = subscription_type
        self.event_id = event_id
        self.event_type = event_type
        # kwargs содержит дополнительные аргументы, которые могут быть переданы
        for key, value in kwargs.items():
            setattr(self, key, value)


class DatabaseEntity:
    def __init__(self, database_type: DatabaseTypes, code=None, name=None, **kwargs):
        self.database_type = database_type
        self.code = code
        self.name = name
        for key, value in kwargs.items():
            setattr(self, key, value)



class MassiveResult:
    def __init__(self, result_type: ResultsType, count = None, total_count = None, channel = None, items = None, channels = None, **kwargs):
        self.result_type = result_type
        if count:
            self.count = count
        if total_count:
            self.total_count = total_count
        if channel:
            self.channel = Channel(**channel)
        
        if items:
            if result_type == ResultsType.POST :
                self.items = [Post(**post) for post in items]

            elif result_type == ResultsType.STORIES:
                self.items = [Story(**story) for story in items]
            
            elif result_type == ResultsType.MENTIONS:
                self.items = [Mention(**mention) for mention in items]
            
            elif result_type == ResultsType.MENTIONS_CHANNEL:
                self.items = [MentionChannel(**mention) for mention in items]

            elif result_type == ResultsType.FORWARDS:
                self.items = [Forward(**fr) for fr in items]
            
            elif result_type == ResultsType.CHANNELS:
                self.items = [Channel(**chan) for chan in items]

        if channels:
            self.channels = [Channel(**chan) for chan in channels]
        for key, value in kwargs.items():
            setattr(self, key, value)



class DynamicData:
    def __init__(self, dynamic_type, period, **kwargs):
        self.dynamic_type = dynamic_type
        self.period = period

        for key, value in kwargs.items():
            setattr(self, key, value)



from enum import Enum


class RequestsMethods(Enum):
    GET = "GET"
    POST = "POST"


class RequestsCategory(Enum):
    CHANNELS = "channels"
    POSTS = "posts"
    STORIES = "stories"
    WORDS = "words"
    CALLBACK = "callback"
    USAGE = "usage"
    DATABASE = "database"


class ChannelsRequests(Enum):
    GET = ("get", RequestsMethods.GET)
    SEARCH = ("search", RequestsMethods.GET)
    STAT = ("stat", RequestsMethods.GET)
    POSTS = ("posts", RequestsMethods.GET)
    STORIES = ("stories", RequestsMethods.GET)
    MENTIONS = ("mentions", RequestsMethods.GET)
    FORWARDS = ("forwards", RequestsMethods.GET)
    SUBSCRIBERS = ("subscribers", RequestsMethods.GET)
    VIEWS = ("views", RequestsMethods.GET)
    AVG_POSTS_REACH = ("avg-posts-reach", RequestsMethods.GET)
    ER = ("er", RequestsMethods.GET)
    ERR = ("err", RequestsMethods.GET)
    ERR24 = ("err24", RequestsMethods.GET)
    ADD = ("add", RequestsMethods.POST)


class PostsRequests(Enum):
    GET = ("get", RequestsMethods.GET)
    STAT = ("stat", RequestsMethods.GET)
    STAT_MULTI = ("stat-multi", RequestsMethods.GET)
    SEARCH = ("search", RequestsMethods.GET)


class StoriesRequests(Enum):
    GET = ("get", RequestsMethods.GET)
    STAT = ("stat", RequestsMethods.GET)
    STAT_MULTI = ("stat-multi", RequestsMethods.GET)


class WordsRequests(Enum):
    MENTIONS_BY_PERIOD = ("mentions-by-period", RequestsMethods.GET)
    MENTIONS_BY_CHANNELS = ("mentions-by-channels", RequestsMethods.GET)


class CallbackRequests(Enum):
    SET_CALLBACK_URL = ("set-callback-url", RequestsMethods.POST)
    GET_CALLBACK_INFO = ("get-callback-info", RequestsMethods.GET)
    SUBSCRIBE_CHANNEL = ("subscribe-channel", RequestsMethods.POST)
    SUBSCRIBE_WORD = ("subscribe-word", RequestsMethods.POST)
    SUBSCRIPTIONS_LIST = ("subscriptions-list", RequestsMethods.GET)
    UNSUBSCRIBE = ("unsubscribe", RequestsMethods.POST)


class UsageRequests(Enum):
    STAT = ("stat", RequestsMethods.GET)


class DatabaseRequests(Enum):
    CATEGORIES = ("categories", RequestsMethods.GET)
    COUNTRIES = ("countries", RequestsMethods.GET)
    LANGUAGES = ("languages", RequestsMethods.GET)


class MediaTypes(Enum):
    MEDIA_PHOTO = "mediaPhoto"
    MEDIA_DOCUMENT = "mediaDocument"
    MEDIA_GEO = "mediaGeo"
    MEDIA_GEO_LIVE = "mediaGeoLive"
    MEDIA_VENUE = "mediaVenue"
    MEDIA_CONTACT = "mediaContact"
    MEDIA_GAME = "mediaGame"
    MEDIA_INVOICE = "mediaInvoice"


class DatabaseTypes(Enum):
    CATEGORIES = "categories"
    COUNTRIES = "countries"
    LANGUAGES = "languages"


class DynamicType(Enum):
    SUBSCRIBERS = 1
    VIEWS = 2
    AVG_POSTS_REACH = 3
    ER = 4
    ERR = 5
    ERR24 = 6
    MENTIONS_BY_PERIOD = 7


class ResultsType(Enum):
    POST = 1
    STORIES = 2
    MENTIONS = 3
    MENTIONS_CHANNEL = 6
    FORWARDS = 4
    CHANNELS = 5

class ReturnTypes(Enum):
    OBJECT = 1
    LIST = 2
    


from os import environ
import unittest

from dotenv import load_dotenv
from krypper_tgstat import classes, enums, exceptions, tg_stat

load_dotenv()

class TGStatSyncTest(unittest.TestCase):

    def test_exeptions(self):
        self.assertRaises(exceptions.TGStatAuthError, tg_stat.TGStatSync, "")
        self.assertRaises(exceptions.TGStatAuthError, tg_stat.TGStatSync, "000")
        tgs = tg_stat.TGStatSync("f", tests=True)
        self.assertRaises(exceptions.TGStatTypeError, tgs.api, category=enums.RequestsCategory.CALLBACK, sub_category=enums.DatabaseRequests.CATEGORIES)

        
    def test_get_databases(self):
        pass
        # tgs = tg_stat.TGStatSync(environ.get("TOKEN"))
        # categories = tgs.api(enums.RequestsCategory.DATABASE, enums.DatabaseRequests.CATEGORIES)
        # countries = tgs.api(enums.RequestsCategory.DATABASE, enums.DatabaseRequests.COUNTRIES)
        # languages = tgs.api(enums.RequestsCategory.DATABASE, enums.DatabaseRequests.LANGUAGES)
        # self.assertIsInstance(categories[0], classes.DatabaseEntity, "Database not return DatabaseEntity in categories")
        # self.assertIsInstance(countries[0], classes.DatabaseEntity, "Database not return DatabaseEntity in countries")
        # self.assertIsInstance(languages[0], classes.DatabaseEntity, "Database not return DatabaseEntity in languages")

        # self.assertEqual(categories[0].database_type, enums.DatabaseTypes.CATEGORIES, f"Not correct db type in category : {categories[0].database_type}")
        # self.assertEqual(countries[0].database_type, enums.DatabaseTypes.COUNTRIES, f"Not correct db type in countries : {countries[0].database_type}")
        # self.assertEqual(languages[0].database_type, enums.DatabaseTypes.LANGUAGES, f"Not correct db type in languages : {languages[0].database_type}")

    
    def test_get_channel_info(self):
        tgs = tg_stat.TGStatSync(environ.get("0000"), tests=True)
        null = None
        data = {
            "status": "ok",
            "response": {
                "id": 321,
                "link": "t.me/varlamov",
                "peer_type": "channel",
                "username": "@varlamov",
                "active_usernames": [
                    "@varlamov"
                ],
                "title": "Varlamov.ru",
                "about": "Илья Варламов. Make Russia warm again! ...",
                "category": "Блоги",
                "country": "Россия",
                "language": "Русский",
                "image100": "//static.tgstat.ru/public/images/channels/_100/ca/caf1a3dfb505ffed0d024130f58c5cfa.jpg",
                "image640": "//static.tgstat.ru/public/images/channels/_0/ca/caf1a3dfb505ffed0d024130f58c5cfa.jpg",
                "participants_count": 154800,
                "tgstat_restrictions": {      # ограничения, наложенные на канал (если ограничений нет - будет возвращен пустой массив)
                    "red_label": True,        # канал помечен красной меткой (за накрутку) на TGStat.ru
                    "black_label": True,      # канал помечен черной меткой (за мошенничество) на TGStat.ru
                }
            }
        }

        result = tgs.get_result(data, enums.ChannelsRequests.GET)
        self.assertIsInstance(result, classes.Channel, "Channel result not a Channel type")

        data = {
            "status": "ok",
            "response": {
                "count": 3,
                "items": [
                    {
                        "id": 53248,
                        "link": "t.me/tg_analytics",
                        "peer_type": "channel",
                        "username": "@tg_analytics",
                        "title": "Telegram Analytics",
                        "about": "Канал проекта Telegram Analytics. \nЗдесь будут появляться последние новости проекта https://tgstat.ru \n\nЧат: @tg_analytics_chat - вопросы, предложения, замечания - всё сюда.\nСтраница проекта в ВК: https://vk.com/tg_analytics",
                        "image100": "//static10.tgstat.ru/channels/_100/1b/1ba75ef1c643f82ac4a09c7aa43bd3ff.jpg",
                        "image640": "//static10.tgstat.ru/channels/_0/1b/1ba75ef1c643f82ac4a09c7aa43bd3ff.jpg",
                        "participants_count": 21905
                    },
                    {
                        "id": 123357,
                        "link": "t.me/AnalyticsFree",
                        "peer_type": "chat",
                        "username": "@AnalyticsFree",
                        "title": "Бесплатные разборы каналов Telegram",
                        "about": "Я делаю разборы Telegram-каналов.\n\nЕсли вы хотите, чтоб я сделал разбор вашего канала напишите мне @LoikoR ссылку на ваш канал с меткой «на разбор».\n\nРазбираю все по пунктам и бесплатно.",
                        "image100": "//static10.tgstat.ru/channels/_100/b6/b6a1d5de6e0101f3886464727fc6fb22.jpg",
                        "image640": "//static10.tgstat.ru/channels/_0/b6/b6a1d5de6e0101f3886464727fc6fb22.jpg",
                        "participants_count": 21
                    },
                    {
                        "id": 798202,
                        "link": "t.me/telega_analytics",
                        "peer_type": "channel",
                        "username": "@telega_analytics",
                        "title": "Telegram Analytics",
                        "about": "Привет, мы поможем тебе прокачать свой канал, разместим его на всех популярных сайтах рекламы телеграмм бесплатно, слишком много интересных идей которые никто не видит!",
                        "image100": "//static10.tgstat.ru/channels/_100/32/322f3e36cdffba89c2168fd1244ca1ff.jpg",
                        "image640": "//static10.tgstat.ru/channels/_0/32/322f3e36cdffba89c2168fd1244ca1ff.jpg",
                        "participants_count": 3
                    }
                ]
            }
        }
        result = tgs.get_result(data, enums.ChannelsRequests.SEARCH)
        self.assertIsInstance(result, classes.MassiveResult, "Channel result not a Channel type")

        data = {
            "status": "ok",
            "response": {
                "id": 118,                           # Внутренний ID канала в TGStat
                "title": "РИА Новости",              # Название канала
                "username": "@rian_ru",              # Username канала
                "peer_type": "channel",              # Тип (канал/чат)
                "participants_count": 2048184,       # Количество подписчиков канала на момент запроса
                "avg_post_reach": 541540,            # Средний охват публикации
                "adv_post_reach_12h": 475712,        # Средний рекламный охват публикации за 12 часов
                "adv_post_reach_24h": 554476,        # Средний рекламный охват публикации за 24 часа
                "adv_post_reach_48h": 580952,        # Средний рекламный охват публикации за 48 часов
                "err_percent": 26.4,                 # Процент вовлеченности подписчиков (ERR %)
                "err24_percent": 25.2,               # Процент вовлеченности подписчиков в просмотр поста за первые 24 часа (ERR24 %)
                "er_percent": 11.11,                 # Коэффициент вовлеченности подписчиков во взаимодействия с постом (реакция, пересылка, комментарий)        
                "daily_reach": 35496444,             # Cуммарный дневной охват
                "ci_index": 8737.68,                 # Индекс цитирования (ИЦ)
                "mentions_count": 171477,            # Количество упоминаний канала в других каналах
                "forwards_count": 472536,            # Количество репостов в другие каналы
                "mentioning_channels_count": 18740,  # Количество каналов, упоминающих данный канал
                "posts_count": 53500,                # Общее количество неудаленных публикаций в канале
            }
        }

        result = tgs.get_result(data, enums.ChannelsRequests.STAT)
        self.assertIsInstance(result, classes.ChannelStatistic)


        data = {
            "status": "ok",
            "response": {
                "count": 50,
                "total_count": 8007,
                "channel": {
                    "id": 7377,
                    "link": "t.me/breakingmash",
                    "username": "@breakingmash",
                    "title": "Mash",
                    "about": "Помахаться и обсудить новости - @mash_chat ...",
                    "image100": "//static2.tgstat.com/public/images/channels/_100/a7/a76c0abe2b7b1b79e70f0073f43c3b44.jpg",
                    "image640": "//static2.tgstat.com/public/images/channels/_0/a7/a76c0abe2b7b1b79e70f0073f43c3b44.jpg",
                    "participants_count": 431868
                },
                "items": [
                    {
                        "id": 3598980241,
                        "date": 1540123429,
                        "views": 148382,
                        "link": "t.me/breakingmash/8419",
                        "channel_id": 7377,
                        "forwarded_from": None,
                        "is_deleted": 0,
                        "text": "В Твери заправщик принял лишнего и решил, ...",
                        "media": {
                            "media_type": "mediaDocument",
                            "mime_type": "video/mp4",
                            "size": 5085138
                        }
                    },
                ]
            }
        }

        result = tgs.get_result(data, enums.ChannelsRequests.POSTS)
        self.assertIsInstance(result, classes.MassiveResult)

        
        data = {
            "status": "ok",
            "response": {
                "count": 8,
                "total_count": 10,        
                "channel": {
                    "id": 7377,
                    "tg_id": 1036240821,
                    "link": "t.me/meduzalive",
                    "peer_type": "channel",
                    "username": "@meduzalive",
                    "active_usernames": [
                        "@meduzalive"
                    ],
                    "title": "Медуза — LIVE",
                    "about": "Главный телеграм-канал «Медузы». Для связи: @meduzalovesyou\n\nПриложение для iOS https://mdza.io/JtSJ9t50Ww4\nИ для Android https://mdza.io/IQkzDh0RHw4\n\nРассылка Signal в телеграме: @meduzasignal",
                    "category": "Новости и СМИ",
                    "country": "Россия",
                    "language": "Русский",
                    "image100": "//static10.tgstat.ru/channels/_100/ad/ad61ab143223efbc24c7d2583be69251.jpg",
                    "image640": "//static1.tgstat.ru/channels/_0/ad/ad61ab143223efbc24c7d2583be69251.jpg",
                    "participants_count": 1211062,
                    "tgstat_restrictions": []
                },
                "items": [
                    {
                        "id": 2,
                        "date": 1696843128,
                        "views": 23483,
                        "link": "t.me/meduzalive/s/18",
                        "channel_id": 74,
                        "is_expired": 1,
                        "expire_at": 1697015928,
                        "caption": "Мой первый день преподавателя)",
                        "media": {
                            "file_size": 9184495,
                            "file_url": "https://static23.tgcnt.ru/stories/_0/32/321b22809d2f98d3c7d7cd08154aaeda.mp4",
                            "file_thumbnail_url": "https://static20.tgcnt.ru/stories/_720/d7/d726d7f5e89acf67d01e4a98afcd9f1e.jpg"
                        }
                    },
                ]
            }
        }


        result = tgs.get_result(data, enums.ChannelsRequests.STORIES)
        self.assertIsInstance(result, classes.MassiveResult)


        data = {
            "status": "ok",
            "response": {
                "items": [
                    {
                        "mentionId": 48258272,
                        "mentionType": "channel",
                        "postId": 4375814870,
                        "postLink": "https://t.me/Heath_Ledger_media/51932",
                        "postDate": 1543487975,
                        "channelId": 197080
                    },
                    {
                        "mentionId": 48254456,
                        "mentionType": "channel",
                        "postId": 4375344988,
                        "postLink": "https://t.me/zradaperemoga/2865",
                        "postDate": 1543487209,
                        "channelId": 79853
                    }
                ],
                "channels": [
                    {
                        "id": 79853,
                        "link": "t.me/zradaperemoga",
                        "username": "@zradaperemoga",
                        "title": "Зрада чи Перемога",
                        "about": "Реальные новости из украинского зазеркалья. Телеграмируем из матери городов русских (Киев - не без ватников).\nДля связи: zperemoga78@mail.ru",
                        "image100": "//static2.tgstat.com/public/images/channels/_100/ac/ac2c1fd09bc875e9e64d78c947c38128.jpg",
                        "image640": "//static2.tgstat.com/public/images/channels/_0/ac/ac2c1fd09bc875e9e64d78c947c38128.jpg",
                        "participants_count": 12921
                    },
                    {
                        "id": 197080,
                        "link": "t.me/Heath_Ledger_media",
                        "username": "@Heath_Ledger_media",
                        "title": "Хит Леджер",
                        "about": "Новости, которые мы заслужили.\nВсе самое свежее про вільну і незалежну тут!\nДля связи - @nika_toy",
                        "image100": "//static2.tgstat.com/public/images/channels/_100/97/97f0a0d896218504dc12fc312a433fe0.jpg",
                        "image640": "//static2.tgstat.com/public/images/channels/_0/97/97f0a0d896218504dc12fc312a433fe0.jpg",
                        "participants_count": 3306
                    },
                    
                ]
            }
        }


        result = tgs.get_result(data, enums.ChannelsRequests.MENTIONS)
        self.assertIsInstance(result, classes.MassiveResult)

        data = {
            "status": "ok",
            "response": {
                "items": [
                    {
                        "forwardId": 29244863,
                        "sourcePostId": 29470001798,
                        "postId": 4221534307,
                        "postLink": "https://t.me/telebrend/429",
                        "postDate": 1542823702,
                        "channelId": 217945
                    },
                    {
                        "forwardId": 28132523,
                        "sourcePostId": 29464481491,
                        "postId": 4128289212,
                        "postLink": "https://t.me/telepulse/289",
                        "postDate": 1542451613,
                        "channelId": 194251
                    }
                ],
                "channels": [
                    {
                        "id": 194251,
                        "link": "t.me/telepulse",
                        "username": "@telepulse",
                        "title": "Пульс Telegram",
                        "about": "Самые интересные события, происходящие в Telegram. \n\n▫️Каналы, стремительно набирающие популярность;\n▫️Сводки по самым популярным и цитируемым публикациям за день;\n▫️Тренды недели - все здесь!\n\nДержи руку на пульсе!",
                        "image100": "//static.tgstat.ru/public/images/channels/_100/76/764b7b71a9162b27d30a1750e17230c4.jpg",
                        "image640": "//static.tgstat.ru/public/images/channels/_0/76/764b7b71a9162b27d30a1750e17230c4.jpg",
                        "participants_count": 498
                    },
                    {
                        "id": 217945,
                        "link": "t.me/telebrend",
                        "username": "@telebrend",
                        "title": "Телеграм БРЕНД 🔝",
                        "about": "Продвижение и заработок в Telegram\n😊 Новичкам 😎 Средним 😜 Профи\n\n📌 Запись на консультацию https://t.me/telebrend/241\n\n✅ По вопросам сотрудничества \nи рекламе @reklama_dengi\n\nБот-автоответчик 🤖 @telebrend_bot",
                        "image100": "//static.tgstat.ru/public/images/channels/_100/e8/e8acde5aeadc76bab05dc26544259d2a.jpg",
                        "image640": "//static.tgstat.ru/public/images/channels/_0/e8/e8acde5aeadc76bab05dc26544259d2a.jpg",
                        "participants_count": 172
                    }
                ]
            }
        }


        result = tgs.get_result(data, enums.ChannelsRequests.FORWARDS)
        self.assertIsInstance(result, classes.MassiveResult)

    
    def test_dynamic_info(self):
        tgs = tg_stat.TGStatSync(environ.get("0000"), tests=True)
        data = {
            "status": "ok",
            "response": [
                {
                    "period": "2020-03-11 10:00",           # 11 марта 2020, 10:00
                    "participants_count": 1518              # кол-во подписчиков по состоянию на 10:00 11 марта 2020
                },
                {
                    "period": "2020-03-11 09:00",
                    "participants_count": 1407
                },
                {
                    "period": "2020-03-11 08:00",
                    "participants_count": 1391
                },
                {
                    "period": "2020-03-11 07:00",
                    "participants_count": 1370
                },
                {
                    "period": "2020-03-11 06:00",
                    "participants_count": 1338
                },
            ]
        }
        dynamic_data = tgs.get_result(data, enums.ChannelsRequests.SUBSCRIBERS)
        self.assertIsInstance(dynamic_data[-1], classes.DynamicData, "Channels SUBSCRIBERS not DynamicData class")

        data = {
            "status": "ok",
            "response": [
                {
                    "period": "2018-11-04",             # 4 ноября 2018
                    "views_count": 3985                 # суммарное кол-во просмотров, совершенных 4 ноября 2018 до 23:59
                },
                {
                    "period": "2018-11-03",
                    "views_count": 4010
                },
                {
                    "period": "2018-11-02",
                    "views_count": 2381
                },
            ]
        }
        dynamic_data = tgs.get_result(data, enums.ChannelsRequests.VIEWS)
        self.assertIsInstance(dynamic_data[-1], classes.DynamicData, "Channels VIEWS not DynamicData class")

        data={
            "status": "ok",
            "response": [
                {
                    "period": "2021-11-26",
                    "avg_posts_reach": 6017
                },
                {
                    "period": "2021-11-25",
                    "avg_posts_reach": 5875
                },
                {
                    "period": "2021-11-24",
                    "avg_posts_reach": 5738
                },
            ]
        }
        dynamic_data = tgs.get_result(data, enums.ChannelsRequests.AVG_POSTS_REACH)
        self.assertIsInstance(dynamic_data[-1], classes.DynamicData, "Channels AVG_POSTS_REACH not DynamicData class")

        data={
            "status": "ok",
            "response": [
                {
                    "period": "2021-11-26",
                    "er": 41
                },
                {
                    "period": "2021-11-25",
                    "er": 41.4
                },
                {
                    "period": "2021-11-24",
                    "er": 40.9
                },
            ]
        }
        dynamic_data = tgs.get_result(data, enums.ChannelsRequests.ER)
        self.assertIsInstance(dynamic_data[-1], classes.DynamicData, "Channels ER not DynamicData class")

        data = {
            "status": "ok",
            "response": [
                {
                    "period": "2021-11-26",
                    "err": 41
                },
                {
                    "period": "2021-11-25",
                    "err": 41.4
                },
                {
                    "period": "2021-11-24",
                    "err": 40.9
                },
            ]
        }
        dynamic_data = tgs.get_result(data, enums.ChannelsRequests.ERR)
        self.assertIsInstance(dynamic_data[-1], classes.DynamicData, "Channels ERR not DynamicData class")

        data = {
            "status": "ok",
            "response": [
                {
                    "period": "2021-11-26",
                    "err24": 41
                },
                {
                    "period": "2021-11-25",
                    "err24": 41.4
                },
                {
                    "period": "2021-11-24",
                    "err24": 40.9
                },
            ]
        }
        dynamic_data = tgs.get_result(data, enums.ChannelsRequests.ERR24)
        self.assertIsInstance(dynamic_data[-1], classes.DynamicData, "Channels ERR24 not DynamicData class")
        
        
    def test_posts(self):
        null = None
        tgs = tg_stat.TGStatSync(environ.get("0000"), tests=True)

        data = {
            "status": "ok",
            "response": {
                "id": 1002665528,
                "date": 1523019187,
                "views": 9736,
                "link": "t.me/tg_analytics/130",
                "channel_id": 53248,
                "forwarded_from": null,
                "is_deleted": 0,
                "text": "Хотите узнать кто репостнул или поделился ссылкой на публикацию и при этом не выходить из любимого Телеграмчика — просто перешлите публикацию нашему боту @TGStat_Bot",
                "media": {
                    "media_type": "mediaPhoto",
                    "caption": ""
                }
            }
        }
        result = tgs.get_result(data, sub_category=enums.PostsRequests.GET)
        self.assertIsInstance(result, classes.Post)

        data = {
            "status": "ok",
            "response": {
                "viewsCount": 157210,
                "sharesCount": 723,
                "commentsCount": 1,
                "reactionsCount": 7452,
                "forwardsCount": 3,
                "mentionsCount": 0,
                "forwards": [
                    {
                        "postId": "26784773903",
                        "postLink": "t.me/LEGION_URAL/726365",
                        "postDate": 1659673815,
                        "channelId": 12337001,
                        "peerType": "chat"
                    },
                    {
                        "postId": "26778706543",
                        "postLink": "t.me/moyvictortsoy/983",
                        "postDate": 1659645896,
                        "channelId": 11015249,
                        "peerType": "channel"
                    },
                    {
                        "postId": "26776890651",
                        "postLink": "t.me/p0pizdelki/453004",
                        "postDate": 1659645701,
                        "channelId": 4186970,
                        "peerType": "chat"
                    }
                ],
                "mentions": [],
                "views": [
                    {
                        "date": "2022-08-05 00:41",
                        "viewsGrowth": 32367
                    },
                    {
                        "date": "2022-08-05 01:41",
                        "viewsGrowth": 7566
                    }, 
                    {
                        "date": "2022-08-08 07:41",
                        "viewsGrowth": 313
                    },
                    {
                        "date": "2022-08-08 08:41",
                        "viewsGrowth": 384
                    },
                    {
                        "date": "2022-08-08 09:41",
                        "viewsGrowth": 250
                    },
                ]
            }
        }
        result = tgs.get_result(data, sub_category=enums.PostsRequests.STAT)
        self.assertIsInstance(result, classes.GroupStatistic)

        data = {
            "status": "ok",
            "response": [
                {
                    "postId": 33322446607,
                    "viewsCount": 10355,
                    "sharesCount": 97,
                    "commentsCount": 55,
                    "reactionsCount": 130
                },
                {
                    "postId": 32755689682,
                    "viewsCount": 24846,
                    "sharesCount": 263,
                    "commentsCount": 95,
                    "reactionsCount": 148
                },
                {
                    "postId": 32302735720,
                    "viewsCount": 39015,
                    "sharesCount": 91,
                    "commentsCount": 52,
                    "reactionsCount": 112
                },
                {
                    "postId": 32061730638,
                    "viewsCount": 37303,
                    "sharesCount": 95,
                    "commentsCount": 24,
                    "reactionsCount": 113
                }
            ]
        }
        result = tgs.get_result(data, sub_category=enums.PostsRequests.STAT_MULTI)
        self.assertIsInstance(result[0], classes.UnionStatistic)

        data = {
            "status": "ok",
            "response": {
                "count": 50, 
                "total_count": 27518, 
                "items": [ 
                    {
                        "id": 3584651917, 
                        "date": 1540057519, 
                        "views": 3139, 
                        "shares_count": 12,
                        "comments_count": 0,
                        "reactions_count": 42,
                        "link": "t.me/orfosvinstvo/6325", 
                        "channel_id": 14069, 
                        "forwarded_from": null,  
                        "is_deleted": 0, 
                        "text": "Друзья! Я уверен, что вы ведёте свои телеграм-каналы ...",
                        "snippet": "Друзья! Я уверен, что вы ведёте свои телеграм-каналы ...", 
                        "media": {
                            "media_type": "mediaDocument",
                            "mime_type": "video/mp4",
                            "size": 5085138
                        }
                    },
                ],
                "channels": [ 
                    {
                        "id": 14069, 
                        "link": "t.me/orfosvinstvo", 
                        "username": "@orfosvinstvo", 
                        "title": "Орфосвинство и идиомаркетинг", 
                        "about": "Исправляем ошибки ...", 
                        "image100": "//static.tgstat.ru/...", 
                        "image640": "//static.tgstat.ru/...", 
                        "participants_count": 9097
                    },
                ]
            }
        }
        result = tgs.get_result(data, sub_category=enums.PostsRequests.SEARCH)
        self.assertIsInstance(result, classes.MassiveResult)


    def test_stories(self):
        null = None
        tgs = tg_stat.TGStatSync(environ.get("0000"), tests=True)

        data = {
            "status": "ok",
            "response": {
                "id": 7939137,
                "date": 1701281859,
                "views": 218410,
                "link": "t.me/breakingmash/s/35",
                "channel_id": 7377,
                "is_expired": 1,
                "expire_at": 1701368259,
                "caption": "Капелька новых поправок к законам в нашей сторис. Бусты как всегда по ссылке: https://t.me/breakingmash?boost",
                "media": {
                    "file_size": 24708968,
                    "file_url": null,
                    "file_thumbnail_url": "https://static25.tgcnt.ru/stories/_180/9d/9d2c28eda69a445965639cd2b1f9e4fd.jpg"
                }
            }
        }
        result = tgs.get_result(data, sub_category=enums.StoriesRequests.GET)
        self.assertIsInstance(result, classes.Story)


        data = {
            "status": "ok",
            "response": {
                "viewsCount": 218410,
                "forwardsCount": 130,        
                "reactionsCount": 9953,       
                "views": [
                    {
                        "date": "2023-11-29 22:17",
                        "viewsGrowth": 28272
                    },
                    {
                        "date": "2023-11-29 23:17",
                        "viewsGrowth": 20169
                    },
                    {
                        "date": "2023-11-30 00:17",
                        "viewsGrowth": 12194
                    },
                    {
                        "date": "2023-11-30 21:17",
                        "viewsGrowth": 9099
                    }
                ]
            }
        }
        result = tgs.get_result(data, sub_category=enums.StoriesRequests.STAT)
        self.assertIsInstance(result, classes.GroupStatistic)

        data = {
            "status": "ok",
            "response": [
                {
                    "storyId": 21176184921,
                    "viewsCount": 1281,
                    "sharesCount": 83,          
                    "reactionsCount": 105
                },
                {
                    "storyId": 28776184920,
                    "viewsCount": 2729,
                    "sharesCount": 192,            
                    "reactionsCount": 123
                },
                {
                    "storyId": 22776184919,
                    "viewsCount": 3007,
                    "sharesCount": 62,            
                    "reactionsCount": 98
                },
                {
                    "storyId": 26476184918,
                    "viewsCount": 3201,
                    "sharesCount": 74,            
                    "reactionsCount": 85
                }
            ]
        }
        result = tgs.get_result(data, sub_category=enums.StoriesRequests.STAT_MULTI)
        self.assertIsInstance(result[0], classes.UnionStatistic)


    def test_mentions(self):
        null = None
        tgs = tg_stat.TGStatSync(environ.get("0000"), tests=True)
        data = {
            "status": "ok",
            "response": {
                "items": [
                    {
                        "period": "2018-11-04",
                        "mentions_count": 11,
                        "views_count": 6781
                    },
                    {
                        "period": "2018-11-03",
                        "mentions_count": 27,
                        "views_count": 13097
                    },
                    {
                        "period": "2018-11-02",
                        "mentions_count": 38,
                        "views_count": 19091
                    },
                ]
            }
        }
        result = tgs.get_result(data, sub_category=enums.WordsRequests.MENTIONS_BY_PERIOD)
        self.assertIsInstance(result[0], classes.DynamicData)

        data = {
            "status": "ok",
            "response": {
                "items": [
                    {
                        "channel_id": 74647,
                        "mentions_count": 4544,
                        "views_count": 78710,
                        "last_mention_date": 1572539401
                    },
                    {
                        "channel_id": 55422,
                        "mentions_count": 1,
                        "views_count": 900,
                        "last_mention_date": 1572204557
                    },
                    {
                        "channel_id": 63694,
                        "mentions_count": 1,
                        "views_count": 1053,
                        "last_mention_date": 1570826223
                    },
                ],
                "channels": [
                    {
                        "id": 74647,
                        "link": "t.me/newchans",
                        "username": "@newchans",
                        "title": "Новые каналы",
                        "about": "Здесь автоматически публикуются новые каналы, зарегистрированные в Telegram и попавшие в индекс TGStat.",
                        "image100": "//static10.tgstat.ru/channels/_100/a8/a82c47f8c5d7d1259ee13ed84a4be346.jpg",
                        "image640": "//static10.tgstat.ru/channels/_0/a8/a82c47f8c5d7d1259ee13ed84a4be346.jpg",
                        "participants_count": 259
                    },
                    {
                        "id": 55422,
                        "link": "t.me/raskruti",
                        "username": "@raskruti",
                        "title": "Раскрути канал",
                        "about": "Если вам нехрен делать - пишите сюда @neznayca \nА лучше не пишите, а то я добрый, добрый, а могу и на хер послать",
                        "image100": "//static10.tgstat.ru/channels/_100/2e/2e72ed76b7b3b9ce2f15fce64178dfaf.jpg",
                        "image640": "//static10.tgstat.ru/channels/_0/2e/2e72ed76b7b3b9ce2f15fce64178dfaf.jpg",
                        "participants_count": 6521
                    },
                    {
                        "id": 63694,
                        "link": "t.me/pltrk",
                        "username": "@pltrk",
                        "title": "Политрук 2.0",
                        "about": "Подкрепление? Ты и есть подкрепление.\n\nПоддержать: 4432 7300 1577 4617",
                        "image100": "//static10.tgstat.ru/channels/_100/0c/0c3f40425314745073e174541ba5e6ad.jpg",
                        "image640": "//static10.tgstat.ru/channels/_0/0c/0c3f40425314745073e174541ba5e6ad.jpg",
                        "participants_count": 2823
                    },
                ]
            }
        }
        result = tgs.get_result(data, sub_category=enums.WordsRequests.MENTIONS_BY_CHANNELS)
        self.assertIsInstance(result, classes.MassiveResult)

if __name__ == '__main__':
    unittest.main()


from setuptools import setup

"""
:authors: Evgeny Momotov (KrymmyEM)
:license: MIT License
Copyright: (c) 2024 Evgeny
"""

version = "0.1.8"

long_description = ""

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name = "krypper_tgstat",
    version = version,
    description = "Wrapper for TG Stat API writing on Python\nTGStat (https://tgstat.ru API wrapper)",
    long_description = long_description,

    author = "Evgeny Momotov (KrymmyEM)",
    author_email = "evgeny.momotov@gmail.com",
    url = "https://github.com/KrymmyEM/krypper_tgstat",
    download_url = "https://github.com/KrymmyEM/krypper_tgstat/archive/main.zip",

    license = "MIT License. See LICENSE file",
    packages = ["krypper_tgstat"],
    install_requires=[
        "requests",
        "aiohttp"
    ],

    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python :: Implementation :: CPython',
    ]
)


